# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ws.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'ws.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08ws.proto\x12\x08yh_ws_go\" \n\x04INFO\x12\x0b\n\x03seq\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\".\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"\x97\x08\n\x03Msg\x12\x0e\n\x06msg_id\x18\x01 \x01(\t\x12$\n\x06sender\x18\x02 \x01(\x0b\x32\x14.yh_ws_go.Msg.Sender\x12\x0f\n\x07recv_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\x11\n\tchat_type\x18\x05 \x01(\x05\x12&\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x15.yh_ws_go.Msg.Content\x12\x14\n\x0c\x63ontent_type\x18\x07 \x01(\x05\x12\x11\n\ttimestamp\x18\x08 \x01(\x03\x12\x1e\n\x03\x63md\x18\t \x01(\x0b\x32\x11.yh_ws_go.Msg.Cmd\x12\x13\n\x0b\x64\x65lete_time\x18\n \x01(\x03\x12\x14\n\x0cquote_msg_id\x18\x0b \x01(\t\x12\x0f\n\x07msg_seq\x18\x0c \x01(\x03\x12\x11\n\tedit_time\x18\x0e \x01(\x03\x1a\x1f\n\x03\x43md\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a{\n\x06Sender\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\t\x12\x11\n\tchat_type\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\navatar_url\x18\x04 \x01(\t\x12\x0f\n\x07tag_old\x18\x06 \x03(\t\x12\x1a\n\x03tag\x18\x07 \x03(\x0b\x32\r.yh_ws_go.Tag\x1a\xc6\x04\n\x07\x43ontent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07\x62uttons\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x11\n\tfile_name\x18\x04 \x01(\t\x12\x10\n\x08\x66ile_url\x18\x05 \x01(\t\x12\x0c\n\x04\x66orm\x18\x07 \x01(\t\x12\x16\n\x0equote_msg_text\x18\x08 \x01(\t\x12\x13\n\x0bsticker_url\x18\t \x01(\t\x12\x0f\n\x07post_id\x18\n \x01(\t\x12\x12\n\npost_title\x18\x0b \x01(\t\x12\x14\n\x0cpost_content\x18\x0c \x01(\t\x12\x19\n\x11post_content_type\x18\r \x01(\t\x12\x15\n\rexpression_id\x18\x0f \x01(\t\x12\x17\n\x0fquote_image_url\x18\x10 \x01(\t\x12\x18\n\x10quote_image_name\x18\x11 \x01(\t\x12\x11\n\tfile_size\x18\x12 \x01(\x03\x12\x11\n\tvideo_url\x18\x13 \x01(\t\x12\x11\n\taudio_url\x18\x15 \x01(\t\x12\x12\n\naudio_time\x18\x16 \x01(\x03\x12\x17\n\x0fquote_video_url\x18\x17 \x01(\t\x12\x18\n\x10quote_video_time\x18\x18 \x01(\x03\x12\x17\n\x0fsticker_item_id\x18\x19 \x01(\x03\x12\x17\n\x0fsticker_pack_id\x18\x1a \x01(\x03\x12\x11\n\tcall_text\x18\x1d \x01(\t\x12\x18\n\x10\x63\x61ll_status_text\x18  \x01(\t\x12\r\n\x05width\x18! \x01(\x03\x12\x0e\n\x06height\x18\" \x01(\x03\x12\x0b\n\x03tip\x18% \x01(\t\"-\n\rheartbeat_ack\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\"\x88\x01\n\x0cpush_message\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.yh_ws_go.push_message.Data\x1a/\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12\x1a\n\x03msg\x18\x02 \x01(\x0b\x32\r.yh_ws_go.Msg\"\x88\x01\n\x0c\x65\x64it_message\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.yh_ws_go.edit_message.Data\x1a/\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12\x1a\n\x03msg\x18\x02 \x01(\x0b\x32\r.yh_ws_go.Msg\"\xac\x02\n\x11\x66ile_send_message\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .yh_ws_go.file_send_message.Data\x1a\xc8\x01\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12\x37\n\x06sender\x18\x02 \x01(\x0b\x32\'.yh_ws_go.file_send_message.Data.Sender\x1az\n\x06Sender\x12\x14\n\x0csend_user_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\ttemp_code\x18\x03 \x01(\x04\x12\x11\n\tsend_type\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12\x15\n\rsend_deviceId\x18\x06 \x01(\t\"\xc4\x01\n\x0b\x64raft_input\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.yh_ws_go.draft_input.Data\x1am\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12/\n\x05\x64raft\x18\x02 \x01(\x0b\x32 .yh_ws_go.draft_input.Data.Draft\x1a\'\n\x05\x44raft\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\"\xc9\x02\n\x11\x62ot_board_message\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .yh_ws_go.bot_board_message.Data\x1a\xe5\x01\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12:\n\x05\x62oard\x18\x02 \x01(\x0b\x32+.yh_ws_go.bot_board_message.Data.Board_data\x1a\x93\x01\n\nBoard_data\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\t\x12\x11\n\tchat_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x05 \x01(\x05\x12\x18\n\x10last_update_time\x18\x06 \x01(\x03\x12\x10\n\x08\x62ot_name\x18\x07 \x01(\t\"\xf7\x01\n\x0estream_message\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.yh_ws_go.INFO\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.yh_ws_go.stream_message.Data\x1a\x99\x01\n\x04\x44\x61ta\x12\x0b\n\x03\x61ny\x18\x01 \x01(\t\x12\x34\n\x03msg\x18\x02 \x01(\x0b\x32\'.yh_ws_go.stream_message.Data.StreamMsg\x1aN\n\tStreamMsg\x12\x0e\n\x06msg_id\x18\x01 \x01(\t\x12\x0f\n\x07recv_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ws_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INFO']._serialized_start=22
  _globals['_INFO']._serialized_end=54
  _globals['_TAG']._serialized_start=56
  _globals['_TAG']._serialized_end=102
  _globals['_MSG']._serialized_start=105
  _globals['_MSG']._serialized_end=1152
  _globals['_MSG_CMD']._serialized_start=411
  _globals['_MSG_CMD']._serialized_end=442
  _globals['_MSG_SENDER']._serialized_start=444
  _globals['_MSG_SENDER']._serialized_end=567
  _globals['_MSG_CONTENT']._serialized_start=570
  _globals['_MSG_CONTENT']._serialized_end=1152
  _globals['_HEARTBEAT_ACK']._serialized_start=1154
  _globals['_HEARTBEAT_ACK']._serialized_end=1199
  _globals['_PUSH_MESSAGE']._serialized_start=1202
  _globals['_PUSH_MESSAGE']._serialized_end=1338
  _globals['_PUSH_MESSAGE_DATA']._serialized_start=1291
  _globals['_PUSH_MESSAGE_DATA']._serialized_end=1338
  _globals['_EDIT_MESSAGE']._serialized_start=1341
  _globals['_EDIT_MESSAGE']._serialized_end=1477
  _globals['_EDIT_MESSAGE_DATA']._serialized_start=1291
  _globals['_EDIT_MESSAGE_DATA']._serialized_end=1338
  _globals['_FILE_SEND_MESSAGE']._serialized_start=1480
  _globals['_FILE_SEND_MESSAGE']._serialized_end=1780
  _globals['_FILE_SEND_MESSAGE_DATA']._serialized_start=1580
  _globals['_FILE_SEND_MESSAGE_DATA']._serialized_end=1780
  _globals['_FILE_SEND_MESSAGE_DATA_SENDER']._serialized_start=1658
  _globals['_FILE_SEND_MESSAGE_DATA_SENDER']._serialized_end=1780
  _globals['_DRAFT_INPUT']._serialized_start=1783
  _globals['_DRAFT_INPUT']._serialized_end=1979
  _globals['_DRAFT_INPUT_DATA']._serialized_start=1870
  _globals['_DRAFT_INPUT_DATA']._serialized_end=1979
  _globals['_DRAFT_INPUT_DATA_DRAFT']._serialized_start=1940
  _globals['_DRAFT_INPUT_DATA_DRAFT']._serialized_end=1979
  _globals['_BOT_BOARD_MESSAGE']._serialized_start=1982
  _globals['_BOT_BOARD_MESSAGE']._serialized_end=2311
  _globals['_BOT_BOARD_MESSAGE_DATA']._serialized_start=2082
  _globals['_BOT_BOARD_MESSAGE_DATA']._serialized_end=2311
  _globals['_BOT_BOARD_MESSAGE_DATA_BOARD_DATA']._serialized_start=2164
  _globals['_BOT_BOARD_MESSAGE_DATA_BOARD_DATA']._serialized_end=2311
  _globals['_STREAM_MESSAGE']._serialized_start=2314
  _globals['_STREAM_MESSAGE']._serialized_end=2561
  _globals['_STREAM_MESSAGE_DATA']._serialized_start=2408
  _globals['_STREAM_MESSAGE_DATA']._serialized_end=2561
  _globals['_STREAM_MESSAGE_DATA_STREAMMSG']._serialized_start=2483
  _globals['_STREAM_MESSAGE_DATA_STREAMMSG']._serialized_end=2561
# @@protoc_insertion_point(module_scope)
