# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\nyunhu_user\"Z\n\x13\x65mail_login_request\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65viceId\x18\x03 \x01(\t\x12\x10\n\x08platform\x18\x04 \x01(\t\"\xc0\x01\n\x14\x65mail_login_response\x12\x37\n\x06status\x18\x01 \x01(\x0b\x32\'.yunhu_user.email_login_response.Status\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.yunhu_user.email_login_response.Data\x1a#\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x1a\x15\n\x04\x44\x61ta\x12\r\n\x05token\x18\x01 \x01(\t\"\xcc\x01\n\x12user_info_response\x12\x35\n\x06status\x18\x01 \x01(\x0b\x32%.yunhu_user.user_info_response.Status\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.yunhu_user.user_info_response.Data\x1a\x16\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x1a\x34\n\x04\x44\x61ta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\navatar_url\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EMAIL_LOGIN_REQUEST']._serialized_start=26
  _globals['_EMAIL_LOGIN_REQUEST']._serialized_end=116
  _globals['_EMAIL_LOGIN_RESPONSE']._serialized_start=119
  _globals['_EMAIL_LOGIN_RESPONSE']._serialized_end=311
  _globals['_EMAIL_LOGIN_RESPONSE_STATUS']._serialized_start=253
  _globals['_EMAIL_LOGIN_RESPONSE_STATUS']._serialized_end=288
  _globals['_EMAIL_LOGIN_RESPONSE_DATA']._serialized_start=290
  _globals['_EMAIL_LOGIN_RESPONSE_DATA']._serialized_end=311
  _globals['_USER_INFO_RESPONSE']._serialized_start=314
  _globals['_USER_INFO_RESPONSE']._serialized_end=518
  _globals['_USER_INFO_RESPONSE_STATUS']._serialized_start=253
  _globals['_USER_INFO_RESPONSE_STATUS']._serialized_end=275
  _globals['_USER_INFO_RESPONSE_DATA']._serialized_start=466
  _globals['_USER_INFO_RESPONSE_DATA']._serialized_end=518
# @@protoc_insertion_point(module_scope)
