# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: msg.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'msg.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tmsg.proto\x12\x06yh_msg\"7\n\x06Status\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\".\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"\xf3\x07\n\x03Msg\x12\x0e\n\x06msg_id\x18\x01 \x01(\t\x12\"\n\x06sender\x18\x02 \x01(\x0b\x32\x12.yh_msg.Msg.Sender\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\x05\x12$\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x13.yh_msg.Msg.Content\x12\x11\n\tsend_time\x18\x06 \x01(\x03\x12\x1c\n\x03\x63md\x18\x07 \x01(\x0b\x32\x0f.yh_msg.Msg.Cmd\x12\x17\n\x0fmsg_delete_time\x18\x08 \x01(\x03\x12\x14\n\x0cquote_msg_id\x18\t \x01(\t\x12\x0f\n\x07msg_seq\x18\n \x01(\x03\x12\x11\n\tedit_time\x18\x0c \x01(\x03\x1a!\n\x03\x43md\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x1a\xc6\x04\n\x07\x43ontent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07\x62uttons\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x11\n\tfile_name\x18\x04 \x01(\t\x12\x10\n\x08\x66ile_url\x18\x05 \x01(\t\x12\x0c\n\x04\x66orm\x18\x07 \x01(\t\x12\x16\n\x0equote_msg_text\x18\x08 \x01(\t\x12\x13\n\x0bsticker_url\x18\t \x01(\t\x12\x0f\n\x07post_id\x18\n \x01(\t\x12\x12\n\npost_title\x18\x0b \x01(\t\x12\x14\n\x0cpost_content\x18\x0c \x01(\t\x12\x19\n\x11post_content_type\x18\r \x01(\t\x12\x15\n\rexpression_id\x18\x0f \x01(\t\x12\x17\n\x0fquote_image_url\x18\x10 \x01(\t\x12\x18\n\x10quote_image_name\x18\x11 \x01(\t\x12\x11\n\tfile_size\x18\x12 \x01(\x03\x12\x11\n\tvideo_url\x18\x13 \x01(\t\x12\x11\n\taudio_url\x18\x15 \x01(\t\x12\x12\n\naudio_time\x18\x16 \x01(\x03\x12\x17\n\x0fquote_video_url\x18\x17 \x01(\t\x12\x18\n\x10quote_video_time\x18\x18 \x01(\x03\x12\x17\n\x0fsticker_item_id\x18\x19 \x01(\x03\x12\x17\n\x0fsticker_pack_id\x18\x1a \x01(\x03\x12\x11\n\tcall_text\x18\x1d \x01(\t\x12\x18\n\x10\x63\x61ll_status_text\x18  \x01(\t\x12\r\n\x05width\x18! \x01(\x03\x12\x0e\n\x06height\x18\" \x01(\x03\x12\x0b\n\x03tip\x18% \x01(\t\x1ay\n\x06Sender\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\t\x12\x11\n\tchat_type\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\navatar_url\x18\x04 \x01(\t\x12\x0f\n\x07tag_old\x18\x06 \x03(\t\x12\x18\n\x03tag\x18\x07 \x03(\x0b\x32\x0b.yh_msg.Tag\"O\n\x18list_message_by_seq_send\x12\x0f\n\x07msg_seq\x18\x03 \x01(\x03\x12\x11\n\tchat_type\x18\x04 \x01(\x03\x12\x0f\n\x07\x63hat_id\x18\x05 \x01(\t\"^\n\x13list_message_by_seq\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\x12\x18\n\x03msg\x18\x02 \x03(\x0b\x32\x0b.yh_msg.Msg\x12\r\n\x05total\x18\x03 \x01(\x05\"\x87\x01\n\x1clist_message_by_mid_seq_send\x12\x0f\n\x07msg_seq\x18\x03 \x01(\x03\x12\x11\n\tchat_type\x18\x04 \x01(\x03\x12\x0f\n\x07\x63hat_id\x18\x05 \x01(\t\x12\x0f\n\x07unknown\x18\x06 \x01(\x03\x12\x11\n\tmsg_count\x18\x07 \x01(\x03\x12\x0e\n\x06msg_id\x18\x08 \x01(\t\"b\n\x17list_message_by_mid_seq\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\x12\x18\n\x03msg\x18\x02 \x03(\x0b\x32\x0b.yh_msg.Msg\x12\r\n\x05total\x18\x03 \x01(\x05\"Z\n\x11list_message_send\x12\x11\n\tmsg_count\x18\x02 \x01(\x03\x12\x0e\n\x06msg_id\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\x03\x12\x0f\n\x07\x63hat_id\x18\x05 \x01(\t\"H\n\x0clist_message\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\x12\x18\n\x03msg\x18\x02 \x03(\x0b\x32\x0b.yh_msg.Msg\"\xd7\x06\n\x11send_message_send\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\x03\x12\x32\n\x07\x63ontent\x18\x05 \x01(\x0b\x32!.yh_msg.send_message_send.Content\x12\x14\n\x0c\x63ontent_type\x18\x06 \x01(\x03\x12\x12\n\ncommand_id\x18\x07 \x01(\x03\x12\x14\n\x0cquote_msg_id\x18\x08 \x01(\t\x12.\n\x05media\x18\t \x01(\x0b\x32\x1f.yh_msg.send_message_send.Media\x1a\xc1\x03\n\x07\x43ontent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07\x62uttons\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x04 \x01(\t\x12\x0c\n\x04\x66ile\x18\x05 \x01(\t\x12\x14\n\x0cmentioned_id\x18\x06 \x03(\t\x12\x0c\n\x04\x66orm\x18\x07 \x01(\t\x12\x16\n\x0equote_msg_text\x18\x08 \x01(\t\x12\r\n\x05image\x18\t \x01(\t\x12\x11\n\tmsg_text1\x18\x0b \x01(\t\x12\x11\n\tmsg_text2\x18\x0c \x01(\t\x12\x15\n\rexpression_id\x18\x0f \x01(\t\x12\x17\n\x0fquote_image_url\x18\x10 \x01(\t\x12\x18\n\x10quote_image_name\x18\x11 \x01(\t\x12\x11\n\tfile_size\x18\x12 \x01(\x03\x12\r\n\x05video\x18\x13 \x01(\t\x12\r\n\x05\x61udio\x18\x15 \x01(\t\x12\x12\n\naudio_time\x18\x16 \x01(\x03\x12\x17\n\x0fquote_video_url\x18\x17 \x01(\t\x12\x18\n\x10quote_video_time\x18\x18 \x01(\x03\x12\x17\n\x0fsticker_item_id\x18\x19 \x01(\x03\x12\x17\n\x0fsticker_pack_id\x18\x1a \x01(\x03\x12\x11\n\troom_name\x18\x1d \x01(\t\x1a\xa5\x01\n\x05Media\x12\x10\n\x08\x66ile_key\x18\x01 \x01(\t\x12\x11\n\tfile_hash\x18\x02 \x01(\t\x12\x11\n\tfile_type\x18\x03 \x01(\t\x12\x14\n\x0cimage_height\x18\x05 \x01(\x03\x12\x13\n\x0bimage_width\x18\x06 \x01(\x03\x12\x11\n\tfile_size\x18\x07 \x01(\x03\x12\x11\n\tfile_key2\x18\x08 \x01(\t\x12\x13\n\x0b\x66ile_suffix\x18\t \x01(\t\".\n\x0csend_message\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\"E\n\x0frecall_msg_send\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\x03\",\n\nrecall_msg\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\"K\n\x15recall_msg_batch_send\x12\x0e\n\x06msg_id\x18\x02 \x03(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\x03\"2\n\x10recall_msg_batch\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\"\xe9\x01\n\x11\x65\x64it_message_send\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\x05\x12\x32\n\x07\x63ontent\x18\x05 \x01(\x0b\x32!.yh_msg.edit_message_send.Content\x12\x14\n\x0c\x63ontent_type\x18\x06 \x01(\x03\x12\x14\n\x0cquote_msg_id\x18\x08 \x01(\t\x1a@\n\x07\x43ontent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07\x62uttons\x18\x02 \x01(\t\x12\x16\n\x0equote_msg_text\x18\x08 \x01(\t\".\n\x0c\x65\x64it_message\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.yh_msg.Status\"o\n\x12\x62utton_report_send\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x11\n\tchat_type\x18\x03 \x01(\x03\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x14\n\x0c\x62utton_value\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msg_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STATUS']._serialized_start=21
  _globals['_STATUS']._serialized_end=76
  _globals['_TAG']._serialized_start=78
  _globals['_TAG']._serialized_end=124
  _globals['_MSG']._serialized_start=127
  _globals['_MSG']._serialized_end=1138
  _globals['_MSG_CMD']._serialized_start=397
  _globals['_MSG_CMD']._serialized_end=430
  _globals['_MSG_CONTENT']._serialized_start=433
  _globals['_MSG_CONTENT']._serialized_end=1015
  _globals['_MSG_SENDER']._serialized_start=1017
  _globals['_MSG_SENDER']._serialized_end=1138
  _globals['_LIST_MESSAGE_BY_SEQ_SEND']._serialized_start=1140
  _globals['_LIST_MESSAGE_BY_SEQ_SEND']._serialized_end=1219
  _globals['_LIST_MESSAGE_BY_SEQ']._serialized_start=1221
  _globals['_LIST_MESSAGE_BY_SEQ']._serialized_end=1315
  _globals['_LIST_MESSAGE_BY_MID_SEQ_SEND']._serialized_start=1318
  _globals['_LIST_MESSAGE_BY_MID_SEQ_SEND']._serialized_end=1453
  _globals['_LIST_MESSAGE_BY_MID_SEQ']._serialized_start=1455
  _globals['_LIST_MESSAGE_BY_MID_SEQ']._serialized_end=1553
  _globals['_LIST_MESSAGE_SEND']._serialized_start=1555
  _globals['_LIST_MESSAGE_SEND']._serialized_end=1645
  _globals['_LIST_MESSAGE']._serialized_start=1647
  _globals['_LIST_MESSAGE']._serialized_end=1719
  _globals['_SEND_MESSAGE_SEND']._serialized_start=1722
  _globals['_SEND_MESSAGE_SEND']._serialized_end=2577
  _globals['_SEND_MESSAGE_SEND_CONTENT']._serialized_start=1960
  _globals['_SEND_MESSAGE_SEND_CONTENT']._serialized_end=2409
  _globals['_SEND_MESSAGE_SEND_MEDIA']._serialized_start=2412
  _globals['_SEND_MESSAGE_SEND_MEDIA']._serialized_end=2577
  _globals['_SEND_MESSAGE']._serialized_start=2579
  _globals['_SEND_MESSAGE']._serialized_end=2625
  _globals['_RECALL_MSG_SEND']._serialized_start=2627
  _globals['_RECALL_MSG_SEND']._serialized_end=2696
  _globals['_RECALL_MSG']._serialized_start=2698
  _globals['_RECALL_MSG']._serialized_end=2742
  _globals['_RECALL_MSG_BATCH_SEND']._serialized_start=2744
  _globals['_RECALL_MSG_BATCH_SEND']._serialized_end=2819
  _globals['_RECALL_MSG_BATCH']._serialized_start=2821
  _globals['_RECALL_MSG_BATCH']._serialized_end=2871
  _globals['_EDIT_MESSAGE_SEND']._serialized_start=2874
  _globals['_EDIT_MESSAGE_SEND']._serialized_end=3107
  _globals['_EDIT_MESSAGE_SEND_CONTENT']._serialized_start=3043
  _globals['_EDIT_MESSAGE_SEND_CONTENT']._serialized_end=3107
  _globals['_EDIT_MESSAGE']._serialized_start=3109
  _globals['_EDIT_MESSAGE']._serialized_end=3155
  _globals['_BUTTON_REPORT_SEND']._serialized_start=3157
  _globals['_BUTTON_REPORT_SEND']._serialized_end=3268
# @@protoc_insertion_point(module_scope)
